# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['IndexArgs', 'Index']

@pulumi.input_type
class IndexArgs:
    def __init__(__self__, *,
                 cluster_name: pulumi.Input[str],
                 col_exprs: pulumi.Input[Sequence[pulumi.Input['IndexColExprArgs']]],
                 obj_name: pulumi.Input['IndexObjNameArgs'],
                 comment: Optional[pulumi.Input[str]] = None,
                 default: Optional[pulumi.Input[bool]] = None,
                 method: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Index resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this index.
        :param pulumi.Input[Sequence[pulumi.Input['IndexColExprArgs']]] col_exprs: The expressions to use as the key for the index.
        :param pulumi.Input['IndexObjNameArgs'] obj_name: The name of the source, view, or materialized view on which you want to create an index.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[bool] default: Creates a default index using all inferred columns are used.
        :param pulumi.Input[str] method: The name of the index method to use.
        :param pulumi.Input[str] name: The identifier for the index.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        """
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "col_exprs", col_exprs)
        pulumi.set(__self__, "obj_name", obj_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if method is not None:
            pulumi.set(__self__, "method", method)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Input[str]:
        """
        The cluster to maintain this index.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter(name="colExprs")
    def col_exprs(self) -> pulumi.Input[Sequence[pulumi.Input['IndexColExprArgs']]]:
        """
        The expressions to use as the key for the index.
        """
        return pulumi.get(self, "col_exprs")

    @col_exprs.setter
    def col_exprs(self, value: pulumi.Input[Sequence[pulumi.Input['IndexColExprArgs']]]):
        pulumi.set(self, "col_exprs", value)

    @property
    @pulumi.getter(name="objName")
    def obj_name(self) -> pulumi.Input['IndexObjNameArgs']:
        """
        The name of the source, view, or materialized view on which you want to create an index.
        """
        return pulumi.get(self, "obj_name")

    @obj_name.setter
    def obj_name(self, value: pulumi.Input['IndexObjNameArgs']):
        pulumi.set(self, "obj_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[bool]]:
        """
        Creates a default index using all inferred columns are used.
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "default", value)

    @property
    @pulumi.getter
    def method(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the index method to use.
        """
        return pulumi.get(self, "method")

    @method.setter
    def method(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "method", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the index.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _IndexState:
    def __init__(__self__, *,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 col_exprs: Optional[pulumi.Input[Sequence[pulumi.Input['IndexColExprArgs']]]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 default: Optional[pulumi.Input[bool]] = None,
                 method: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 obj_name: Optional[pulumi.Input['IndexObjNameArgs']] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Index resources.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this index.
        :param pulumi.Input[Sequence[pulumi.Input['IndexColExprArgs']]] col_exprs: The expressions to use as the key for the index.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the index database.
        :param pulumi.Input[bool] default: Creates a default index using all inferred columns are used.
        :param pulumi.Input[str] method: The name of the index method to use.
        :param pulumi.Input[str] name: The identifier for the index.
        :param pulumi.Input['IndexObjNameArgs'] obj_name: The name of the source, view, or materialized view on which you want to create an index.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the index.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the index schema.
        """
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if col_exprs is not None:
            pulumi.set(__self__, "col_exprs", col_exprs)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if method is not None:
            pulumi.set(__self__, "method", method)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if obj_name is not None:
            pulumi.set(__self__, "obj_name", obj_name)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this index.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter(name="colExprs")
    def col_exprs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IndexColExprArgs']]]]:
        """
        The expressions to use as the key for the index.
        """
        return pulumi.get(self, "col_exprs")

    @col_exprs.setter
    def col_exprs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IndexColExprArgs']]]]):
        pulumi.set(self, "col_exprs", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the index database.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[bool]]:
        """
        Creates a default index using all inferred columns are used.
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "default", value)

    @property
    @pulumi.getter
    def method(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the index method to use.
        """
        return pulumi.get(self, "method")

    @method.setter
    def method(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "method", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the index.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="objName")
    def obj_name(self) -> Optional[pulumi.Input['IndexObjNameArgs']]:
        """
        The name of the source, view, or materialized view on which you want to create an index.
        """
        return pulumi.get(self, "obj_name")

    @obj_name.setter
    def obj_name(self, value: Optional[pulumi.Input['IndexObjNameArgs']]):
        pulumi.set(self, "obj_name", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the index.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the index schema.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)


class Index(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 col_exprs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexColExprArgs']]]]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 default: Optional[pulumi.Input[bool]] = None,
                 method: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 obj_name: Optional[pulumi.Input[pulumi.InputType['IndexObjNameArgs']]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Indexes represent query results stored in memory.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        loadgen_index = materialize.Index("loadgenIndex",
            cluster_name="cluster",
            method="ARRANGEMENT",
            obj_name=materialize.IndexObjNameArgs(
                database_name="database",
                name="source",
                schema_name="schema",
            ))
        ```

        ## Import

        Indexes can be imported using the index id

        ```sh
         $ pulumi import materialize:index/index:Index example_index <region>:<index_id>
        ```

         Index id and information be found in the `mz_catalog.mz_indexes` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this index.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexColExprArgs']]]] col_exprs: The expressions to use as the key for the index.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[bool] default: Creates a default index using all inferred columns are used.
        :param pulumi.Input[str] method: The name of the index method to use.
        :param pulumi.Input[str] name: The identifier for the index.
        :param pulumi.Input[pulumi.InputType['IndexObjNameArgs']] obj_name: The name of the source, view, or materialized view on which you want to create an index.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IndexArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Indexes represent query results stored in memory.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        loadgen_index = materialize.Index("loadgenIndex",
            cluster_name="cluster",
            method="ARRANGEMENT",
            obj_name=materialize.IndexObjNameArgs(
                database_name="database",
                name="source",
                schema_name="schema",
            ))
        ```

        ## Import

        Indexes can be imported using the index id

        ```sh
         $ pulumi import materialize:index/index:Index example_index <region>:<index_id>
        ```

         Index id and information be found in the `mz_catalog.mz_indexes` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param IndexArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IndexArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 col_exprs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexColExprArgs']]]]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 default: Optional[pulumi.Input[bool]] = None,
                 method: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 obj_name: Optional[pulumi.Input[pulumi.InputType['IndexObjNameArgs']]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IndexArgs.__new__(IndexArgs)

            if cluster_name is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_name'")
            __props__.__dict__["cluster_name"] = cluster_name
            if col_exprs is None and not opts.urn:
                raise TypeError("Missing required property 'col_exprs'")
            __props__.__dict__["col_exprs"] = col_exprs
            __props__.__dict__["comment"] = comment
            __props__.__dict__["default"] = default
            __props__.__dict__["method"] = method
            __props__.__dict__["name"] = name
            if obj_name is None and not opts.urn:
                raise TypeError("Missing required property 'obj_name'")
            __props__.__dict__["obj_name"] = obj_name
            __props__.__dict__["region"] = region
            __props__.__dict__["database_name"] = None
            __props__.__dict__["qualified_sql_name"] = None
            __props__.__dict__["schema_name"] = None
        super(Index, __self__).__init__(
            'materialize:index/index:Index',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_name: Optional[pulumi.Input[str]] = None,
            col_exprs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexColExprArgs']]]]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            default: Optional[pulumi.Input[bool]] = None,
            method: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            obj_name: Optional[pulumi.Input[pulumi.InputType['IndexObjNameArgs']]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            schema_name: Optional[pulumi.Input[str]] = None) -> 'Index':
        """
        Get an existing Index resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this index.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IndexColExprArgs']]]] col_exprs: The expressions to use as the key for the index.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the index database.
        :param pulumi.Input[bool] default: Creates a default index using all inferred columns are used.
        :param pulumi.Input[str] method: The name of the index method to use.
        :param pulumi.Input[str] name: The identifier for the index.
        :param pulumi.Input[pulumi.InputType['IndexObjNameArgs']] obj_name: The name of the source, view, or materialized view on which you want to create an index.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the index.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the index schema.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IndexState.__new__(_IndexState)

        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["col_exprs"] = col_exprs
        __props__.__dict__["comment"] = comment
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["default"] = default
        __props__.__dict__["method"] = method
        __props__.__dict__["name"] = name
        __props__.__dict__["obj_name"] = obj_name
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        return Index(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[str]:
        """
        The cluster to maintain this index.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter(name="colExprs")
    def col_exprs(self) -> pulumi.Output[Sequence['outputs.IndexColExpr']]:
        """
        The expressions to use as the key for the index.
        """
        return pulumi.get(self, "col_exprs")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[str]:
        """
        The identifier for the index database.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def default(self) -> pulumi.Output[Optional[bool]]:
        """
        Creates a default index using all inferred columns are used.
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def method(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the index method to use.
        """
        return pulumi.get(self, "method")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the index.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="objName")
    def obj_name(self) -> pulumi.Output['outputs.IndexObjName']:
        """
        The name of the source, view, or materialized view on which you want to create an index.
        """
        return pulumi.get(self, "obj_name")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the index.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[str]:
        """
        The identifier for the index schema.
        """
        return pulumi.get(self, "schema_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetClustersResult',
    'AwaitableGetClustersResult',
    'get_clusters',
    'get_clusters_output',
]

@pulumi.output_type
class GetClustersResult:
    """
    A collection of values returned by GetClusters.
    """
    def __init__(__self__, clusters=None, id=None, region=None):
        if clusters and not isinstance(clusters, list):
            raise TypeError("Expected argument 'clusters' to be a list")
        pulumi.set(__self__, "clusters", clusters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter
    def clusters(self) -> Sequence['outputs.GetClustersClusterResult']:
        """
        The clusters in the account
        """
        return pulumi.get(self, "clusters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")


class AwaitableGetClustersResult(GetClustersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClustersResult(
            clusters=self.clusters,
            id=self.id,
            region=self.region)


def get_clusters(region: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClustersResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_clusters()
    ```


    :param str region: The region in which the resource is located.
    """
    __args__ = dict()
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getClusters:GetClusters', __args__, opts=opts, typ=GetClustersResult).value

    return AwaitableGetClustersResult(
        clusters=pulumi.get(__ret__, 'clusters'),
        id=pulumi.get(__ret__, 'id'),
        region=pulumi.get(__ret__, 'region'))


@_utilities.lift_output_func(get_clusters)
def get_clusters_output(region: Optional[pulumi.Input[Optional[str]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetClustersResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_clusters()
    ```


    :param str region: The region in which the resource is located.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetRolesResult',
    'AwaitableGetRolesResult',
    'get_roles',
    'get_roles_output',
]

@pulumi.output_type
class GetRolesResult:
    """
    A collection of values returned by GetRoles.
    """
    def __init__(__self__, id=None, region=None, roles=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if roles and not isinstance(roles, list):
            raise TypeError("Expected argument 'roles' to be a list")
        pulumi.set(__self__, "roles", roles)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def roles(self) -> Sequence['outputs.GetRolesRoleResult']:
        """
        The roles in the account
        """
        return pulumi.get(self, "roles")


class AwaitableGetRolesResult(GetRolesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRolesResult(
            id=self.id,
            region=self.region,
            roles=self.roles)


def get_roles(region: Optional[str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRolesResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_roles()
    ```


    :param str region: The region in which the resource is located.
    """
    __args__ = dict()
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getRoles:GetRoles', __args__, opts=opts, typ=GetRolesResult).value

    return AwaitableGetRolesResult(
        id=pulumi.get(__ret__, 'id'),
        region=pulumi.get(__ret__, 'region'),
        roles=pulumi.get(__ret__, 'roles'))


@_utilities.lift_output_func(get_roles)
def get_roles_output(region: Optional[pulumi.Input[Optional[str]]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRolesResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_roles()
    ```


    :param str region: The region in which the resource is located.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetMaterializedViewsResult',
    'AwaitableGetMaterializedViewsResult',
    'get_materialized_views',
    'get_materialized_views_output',
]

@pulumi.output_type
class GetMaterializedViewsResult:
    """
    A collection of values returned by GetMaterializedViews.
    """
    def __init__(__self__, database_name=None, id=None, materialized_views=None, region=None, schema_name=None):
        if database_name and not isinstance(database_name, str):
            raise TypeError("Expected argument 'database_name' to be a str")
        pulumi.set(__self__, "database_name", database_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if materialized_views and not isinstance(materialized_views, list):
            raise TypeError("Expected argument 'materialized_views' to be a list")
        pulumi.set(__self__, "materialized_views", materialized_views)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if schema_name and not isinstance(schema_name, str):
            raise TypeError("Expected argument 'schema_name' to be a str")
        pulumi.set(__self__, "schema_name", schema_name)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[str]:
        """
        Limit materialized views to a specific database
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="materializedViews")
    def materialized_views(self) -> Sequence['outputs.GetMaterializedViewsMaterializedViewResult']:
        """
        The materialized views in the account
        """
        return pulumi.get(self, "materialized_views")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[str]:
        """
        Limit materialized views to a specific schema within a specific database
        """
        return pulumi.get(self, "schema_name")


class AwaitableGetMaterializedViewsResult(GetMaterializedViewsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMaterializedViewsResult(
            database_name=self.database_name,
            id=self.id,
            materialized_views=self.materialized_views,
            region=self.region,
            schema_name=self.schema_name)


def get_materialized_views(database_name: Optional[str] = None,
                           region: Optional[str] = None,
                           schema_name: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMaterializedViewsResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_materialized_views()
    materialize = materialize.get_materialized_views(database_name="materialize")
    materialize_schema = materialize.get_materialized_views(database_name="materialize",
        schema_name="schema")
    ```


    :param str database_name: Limit materialized views to a specific database
    :param str region: The region in which the resource is located.
    :param str schema_name: Limit materialized views to a specific schema within a specific database
    """
    __args__ = dict()
    __args__['databaseName'] = database_name
    __args__['region'] = region
    __args__['schemaName'] = schema_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getMaterializedViews:GetMaterializedViews', __args__, opts=opts, typ=GetMaterializedViewsResult).value

    return AwaitableGetMaterializedViewsResult(
        database_name=pulumi.get(__ret__, 'database_name'),
        id=pulumi.get(__ret__, 'id'),
        materialized_views=pulumi.get(__ret__, 'materialized_views'),
        region=pulumi.get(__ret__, 'region'),
        schema_name=pulumi.get(__ret__, 'schema_name'))


@_utilities.lift_output_func(get_materialized_views)
def get_materialized_views_output(database_name: Optional[pulumi.Input[Optional[str]]] = None,
                                  region: Optional[pulumi.Input[Optional[str]]] = None,
                                  schema_name: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMaterializedViewsResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_materialized_views()
    materialize = materialize.get_materialized_views(database_name="materialize")
    materialize_schema = materialize.get_materialized_views(database_name="materialize",
        schema_name="schema")
    ```


    :param str database_name: Limit materialized views to a specific database
    :param str region: The region in which the resource is located.
    :param str schema_name: Limit materialized views to a specific schema within a specific database
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SourceKafkaArgs', 'SourceKafka']

@pulumi.input_type
class SourceKafkaArgs:
    def __init__(__self__, *,
                 kafka_connection: pulumi.Input['SourceKafkaKafkaConnectionArgs'],
                 topic: pulumi.Input[str],
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 envelope: Optional[pulumi.Input['SourceKafkaEnvelopeArgs']] = None,
                 expose_progress: Optional[pulumi.Input['SourceKafkaExposeProgressArgs']] = None,
                 format: Optional[pulumi.Input['SourceKafkaFormatArgs']] = None,
                 include_headers: Optional[pulumi.Input[bool]] = None,
                 include_headers_alias: Optional[pulumi.Input[str]] = None,
                 include_key: Optional[pulumi.Input[bool]] = None,
                 include_key_alias: Optional[pulumi.Input[str]] = None,
                 include_offset: Optional[pulumi.Input[bool]] = None,
                 include_offset_alias: Optional[pulumi.Input[str]] = None,
                 include_partition: Optional[pulumi.Input[bool]] = None,
                 include_partition_alias: Optional[pulumi.Input[str]] = None,
                 include_timestamp: Optional[pulumi.Input[bool]] = None,
                 include_timestamp_alias: Optional[pulumi.Input[str]] = None,
                 key_format: Optional[pulumi.Input['SourceKafkaKeyFormatArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 start_offsets: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 start_timestamp: Optional[pulumi.Input[int]] = None,
                 value_format: Optional[pulumi.Input['SourceKafkaValueFormatArgs']] = None):
        """
        The set of arguments for constructing a SourceKafka resource.
        :param pulumi.Input['SourceKafkaKafkaConnectionArgs'] kafka_connection: The Kafka connection to use in the source.
        :param pulumi.Input[str] topic: The Kafka topic you want to subscribe to.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input['SourceKafkaEnvelopeArgs'] envelope: How Materialize should interpret records (e.g. append-only, upsert)..
        :param pulumi.Input['SourceKafkaExposeProgressArgs'] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input['SourceKafkaFormatArgs'] format: How to decode raw bytes from different formats into data structures Materialize can understand at runtime.
        :param pulumi.Input[bool] include_headers: Include message headers.
        :param pulumi.Input[str] include_headers_alias: Provide an alias for the headers column.
        :param pulumi.Input[bool] include_key: Include a column containing the Kafka message key.
        :param pulumi.Input[str] include_key_alias: Provide an alias for the key column.
        :param pulumi.Input[bool] include_offset: Include an offset column containing the Kafka message offset.
        :param pulumi.Input[str] include_offset_alias: Provide an alias for the offset column.
        :param pulumi.Input[bool] include_partition: Include a partition column containing the Kafka message partition
        :param pulumi.Input[str] include_partition_alias: Provide an alias for the partition column.
        :param pulumi.Input[bool] include_timestamp: Include a timestamp column containing the Kafka message timestamp.
        :param pulumi.Input[str] include_timestamp_alias: Provide an alias for the timestamp column.
        :param pulumi.Input['SourceKafkaKeyFormatArgs'] key_format: Set the key format explicitly.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] start_offsets: Read partitions from the specified offset.
        :param pulumi.Input[int] start_timestamp: Use the specified value to set `START OFFSET` based on the Kafka timestamp.
        :param pulumi.Input['SourceKafkaValueFormatArgs'] value_format: Set the value format explicitly.
        """
        pulumi.set(__self__, "kafka_connection", kafka_connection)
        pulumi.set(__self__, "topic", topic)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if envelope is not None:
            pulumi.set(__self__, "envelope", envelope)
        if expose_progress is not None:
            pulumi.set(__self__, "expose_progress", expose_progress)
        if format is not None:
            pulumi.set(__self__, "format", format)
        if include_headers is not None:
            pulumi.set(__self__, "include_headers", include_headers)
        if include_headers_alias is not None:
            pulumi.set(__self__, "include_headers_alias", include_headers_alias)
        if include_key is not None:
            pulumi.set(__self__, "include_key", include_key)
        if include_key_alias is not None:
            pulumi.set(__self__, "include_key_alias", include_key_alias)
        if include_offset is not None:
            pulumi.set(__self__, "include_offset", include_offset)
        if include_offset_alias is not None:
            pulumi.set(__self__, "include_offset_alias", include_offset_alias)
        if include_partition is not None:
            pulumi.set(__self__, "include_partition", include_partition)
        if include_partition_alias is not None:
            pulumi.set(__self__, "include_partition_alias", include_partition_alias)
        if include_timestamp is not None:
            pulumi.set(__self__, "include_timestamp", include_timestamp)
        if include_timestamp_alias is not None:
            pulumi.set(__self__, "include_timestamp_alias", include_timestamp_alias)
        if key_format is not None:
            pulumi.set(__self__, "key_format", key_format)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if start_offsets is not None:
            pulumi.set(__self__, "start_offsets", start_offsets)
        if start_timestamp is not None:
            pulumi.set(__self__, "start_timestamp", start_timestamp)
        if value_format is not None:
            pulumi.set(__self__, "value_format", value_format)

    @property
    @pulumi.getter(name="kafkaConnection")
    def kafka_connection(self) -> pulumi.Input['SourceKafkaKafkaConnectionArgs']:
        """
        The Kafka connection to use in the source.
        """
        return pulumi.get(self, "kafka_connection")

    @kafka_connection.setter
    def kafka_connection(self, value: pulumi.Input['SourceKafkaKafkaConnectionArgs']):
        pulumi.set(self, "kafka_connection", value)

    @property
    @pulumi.getter
    def topic(self) -> pulumi.Input[str]:
        """
        The Kafka topic you want to subscribe to.
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: pulumi.Input[str]):
        pulumi.set(self, "topic", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def envelope(self) -> Optional[pulumi.Input['SourceKafkaEnvelopeArgs']]:
        """
        How Materialize should interpret records (e.g. append-only, upsert)..
        """
        return pulumi.get(self, "envelope")

    @envelope.setter
    def envelope(self, value: Optional[pulumi.Input['SourceKafkaEnvelopeArgs']]):
        pulumi.set(self, "envelope", value)

    @property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> Optional[pulumi.Input['SourceKafkaExposeProgressArgs']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @expose_progress.setter
    def expose_progress(self, value: Optional[pulumi.Input['SourceKafkaExposeProgressArgs']]):
        pulumi.set(self, "expose_progress", value)

    @property
    @pulumi.getter
    def format(self) -> Optional[pulumi.Input['SourceKafkaFormatArgs']]:
        """
        How to decode raw bytes from different formats into data structures Materialize can understand at runtime.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: Optional[pulumi.Input['SourceKafkaFormatArgs']]):
        pulumi.set(self, "format", value)

    @property
    @pulumi.getter(name="includeHeaders")
    def include_headers(self) -> Optional[pulumi.Input[bool]]:
        """
        Include message headers.
        """
        return pulumi.get(self, "include_headers")

    @include_headers.setter
    def include_headers(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_headers", value)

    @property
    @pulumi.getter(name="includeHeadersAlias")
    def include_headers_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the headers column.
        """
        return pulumi.get(self, "include_headers_alias")

    @include_headers_alias.setter
    def include_headers_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_headers_alias", value)

    @property
    @pulumi.getter(name="includeKey")
    def include_key(self) -> Optional[pulumi.Input[bool]]:
        """
        Include a column containing the Kafka message key.
        """
        return pulumi.get(self, "include_key")

    @include_key.setter
    def include_key(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_key", value)

    @property
    @pulumi.getter(name="includeKeyAlias")
    def include_key_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the key column.
        """
        return pulumi.get(self, "include_key_alias")

    @include_key_alias.setter
    def include_key_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_key_alias", value)

    @property
    @pulumi.getter(name="includeOffset")
    def include_offset(self) -> Optional[pulumi.Input[bool]]:
        """
        Include an offset column containing the Kafka message offset.
        """
        return pulumi.get(self, "include_offset")

    @include_offset.setter
    def include_offset(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_offset", value)

    @property
    @pulumi.getter(name="includeOffsetAlias")
    def include_offset_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the offset column.
        """
        return pulumi.get(self, "include_offset_alias")

    @include_offset_alias.setter
    def include_offset_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_offset_alias", value)

    @property
    @pulumi.getter(name="includePartition")
    def include_partition(self) -> Optional[pulumi.Input[bool]]:
        """
        Include a partition column containing the Kafka message partition
        """
        return pulumi.get(self, "include_partition")

    @include_partition.setter
    def include_partition(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_partition", value)

    @property
    @pulumi.getter(name="includePartitionAlias")
    def include_partition_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the partition column.
        """
        return pulumi.get(self, "include_partition_alias")

    @include_partition_alias.setter
    def include_partition_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_partition_alias", value)

    @property
    @pulumi.getter(name="includeTimestamp")
    def include_timestamp(self) -> Optional[pulumi.Input[bool]]:
        """
        Include a timestamp column containing the Kafka message timestamp.
        """
        return pulumi.get(self, "include_timestamp")

    @include_timestamp.setter
    def include_timestamp(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_timestamp", value)

    @property
    @pulumi.getter(name="includeTimestampAlias")
    def include_timestamp_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the timestamp column.
        """
        return pulumi.get(self, "include_timestamp_alias")

    @include_timestamp_alias.setter
    def include_timestamp_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_timestamp_alias", value)

    @property
    @pulumi.getter(name="keyFormat")
    def key_format(self) -> Optional[pulumi.Input['SourceKafkaKeyFormatArgs']]:
        """
        Set the key format explicitly.
        """
        return pulumi.get(self, "key_format")

    @key_format.setter
    def key_format(self, value: Optional[pulumi.Input['SourceKafkaKeyFormatArgs']]):
        pulumi.set(self, "key_format", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter(name="startOffsets")
    def start_offsets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        Read partitions from the specified offset.
        """
        return pulumi.get(self, "start_offsets")

    @start_offsets.setter
    def start_offsets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "start_offsets", value)

    @property
    @pulumi.getter(name="startTimestamp")
    def start_timestamp(self) -> Optional[pulumi.Input[int]]:
        """
        Use the specified value to set `START OFFSET` based on the Kafka timestamp.
        """
        return pulumi.get(self, "start_timestamp")

    @start_timestamp.setter
    def start_timestamp(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "start_timestamp", value)

    @property
    @pulumi.getter(name="valueFormat")
    def value_format(self) -> Optional[pulumi.Input['SourceKafkaValueFormatArgs']]:
        """
        Set the value format explicitly.
        """
        return pulumi.get(self, "value_format")

    @value_format.setter
    def value_format(self, value: Optional[pulumi.Input['SourceKafkaValueFormatArgs']]):
        pulumi.set(self, "value_format", value)


@pulumi.input_type
class _SourceKafkaState:
    def __init__(__self__, *,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 envelope: Optional[pulumi.Input['SourceKafkaEnvelopeArgs']] = None,
                 expose_progress: Optional[pulumi.Input['SourceKafkaExposeProgressArgs']] = None,
                 format: Optional[pulumi.Input['SourceKafkaFormatArgs']] = None,
                 include_headers: Optional[pulumi.Input[bool]] = None,
                 include_headers_alias: Optional[pulumi.Input[str]] = None,
                 include_key: Optional[pulumi.Input[bool]] = None,
                 include_key_alias: Optional[pulumi.Input[str]] = None,
                 include_offset: Optional[pulumi.Input[bool]] = None,
                 include_offset_alias: Optional[pulumi.Input[str]] = None,
                 include_partition: Optional[pulumi.Input[bool]] = None,
                 include_partition_alias: Optional[pulumi.Input[str]] = None,
                 include_timestamp: Optional[pulumi.Input[bool]] = None,
                 include_timestamp_alias: Optional[pulumi.Input[str]] = None,
                 kafka_connection: Optional[pulumi.Input['SourceKafkaKafkaConnectionArgs']] = None,
                 key_format: Optional[pulumi.Input['SourceKafkaKeyFormatArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 start_offsets: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 start_timestamp: Optional[pulumi.Input[int]] = None,
                 topic: Optional[pulumi.Input[str]] = None,
                 value_format: Optional[pulumi.Input['SourceKafkaValueFormatArgs']] = None):
        """
        Input properties used for looking up and filtering SourceKafka resources.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input['SourceKafkaEnvelopeArgs'] envelope: How Materialize should interpret records (e.g. append-only, upsert)..
        :param pulumi.Input['SourceKafkaExposeProgressArgs'] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input['SourceKafkaFormatArgs'] format: How to decode raw bytes from different formats into data structures Materialize can understand at runtime.
        :param pulumi.Input[bool] include_headers: Include message headers.
        :param pulumi.Input[str] include_headers_alias: Provide an alias for the headers column.
        :param pulumi.Input[bool] include_key: Include a column containing the Kafka message key.
        :param pulumi.Input[str] include_key_alias: Provide an alias for the key column.
        :param pulumi.Input[bool] include_offset: Include an offset column containing the Kafka message offset.
        :param pulumi.Input[str] include_offset_alias: Provide an alias for the offset column.
        :param pulumi.Input[bool] include_partition: Include a partition column containing the Kafka message partition
        :param pulumi.Input[str] include_partition_alias: Provide an alias for the partition column.
        :param pulumi.Input[bool] include_timestamp: Include a timestamp column containing the Kafka message timestamp.
        :param pulumi.Input[str] include_timestamp_alias: Provide an alias for the timestamp column.
        :param pulumi.Input['SourceKafkaKafkaConnectionArgs'] kafka_connection: The Kafka connection to use in the source.
        :param pulumi.Input['SourceKafkaKeyFormatArgs'] key_format: Set the key format explicitly.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this source.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] start_offsets: Read partitions from the specified offset.
        :param pulumi.Input[int] start_timestamp: Use the specified value to set `START OFFSET` based on the Kafka timestamp.
        :param pulumi.Input[str] topic: The Kafka topic you want to subscribe to.
        :param pulumi.Input['SourceKafkaValueFormatArgs'] value_format: Set the value format explicitly.
        """
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if envelope is not None:
            pulumi.set(__self__, "envelope", envelope)
        if expose_progress is not None:
            pulumi.set(__self__, "expose_progress", expose_progress)
        if format is not None:
            pulumi.set(__self__, "format", format)
        if include_headers is not None:
            pulumi.set(__self__, "include_headers", include_headers)
        if include_headers_alias is not None:
            pulumi.set(__self__, "include_headers_alias", include_headers_alias)
        if include_key is not None:
            pulumi.set(__self__, "include_key", include_key)
        if include_key_alias is not None:
            pulumi.set(__self__, "include_key_alias", include_key_alias)
        if include_offset is not None:
            pulumi.set(__self__, "include_offset", include_offset)
        if include_offset_alias is not None:
            pulumi.set(__self__, "include_offset_alias", include_offset_alias)
        if include_partition is not None:
            pulumi.set(__self__, "include_partition", include_partition)
        if include_partition_alias is not None:
            pulumi.set(__self__, "include_partition_alias", include_partition_alias)
        if include_timestamp is not None:
            pulumi.set(__self__, "include_timestamp", include_timestamp)
        if include_timestamp_alias is not None:
            pulumi.set(__self__, "include_timestamp_alias", include_timestamp_alias)
        if kafka_connection is not None:
            pulumi.set(__self__, "kafka_connection", kafka_connection)
        if key_format is not None:
            pulumi.set(__self__, "key_format", key_format)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if start_offsets is not None:
            pulumi.set(__self__, "start_offsets", start_offsets)
        if start_timestamp is not None:
            pulumi.set(__self__, "start_timestamp", start_timestamp)
        if topic is not None:
            pulumi.set(__self__, "topic", topic)
        if value_format is not None:
            pulumi.set(__self__, "value_format", value_format)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def envelope(self) -> Optional[pulumi.Input['SourceKafkaEnvelopeArgs']]:
        """
        How Materialize should interpret records (e.g. append-only, upsert)..
        """
        return pulumi.get(self, "envelope")

    @envelope.setter
    def envelope(self, value: Optional[pulumi.Input['SourceKafkaEnvelopeArgs']]):
        pulumi.set(self, "envelope", value)

    @property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> Optional[pulumi.Input['SourceKafkaExposeProgressArgs']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @expose_progress.setter
    def expose_progress(self, value: Optional[pulumi.Input['SourceKafkaExposeProgressArgs']]):
        pulumi.set(self, "expose_progress", value)

    @property
    @pulumi.getter
    def format(self) -> Optional[pulumi.Input['SourceKafkaFormatArgs']]:
        """
        How to decode raw bytes from different formats into data structures Materialize can understand at runtime.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: Optional[pulumi.Input['SourceKafkaFormatArgs']]):
        pulumi.set(self, "format", value)

    @property
    @pulumi.getter(name="includeHeaders")
    def include_headers(self) -> Optional[pulumi.Input[bool]]:
        """
        Include message headers.
        """
        return pulumi.get(self, "include_headers")

    @include_headers.setter
    def include_headers(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_headers", value)

    @property
    @pulumi.getter(name="includeHeadersAlias")
    def include_headers_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the headers column.
        """
        return pulumi.get(self, "include_headers_alias")

    @include_headers_alias.setter
    def include_headers_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_headers_alias", value)

    @property
    @pulumi.getter(name="includeKey")
    def include_key(self) -> Optional[pulumi.Input[bool]]:
        """
        Include a column containing the Kafka message key.
        """
        return pulumi.get(self, "include_key")

    @include_key.setter
    def include_key(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_key", value)

    @property
    @pulumi.getter(name="includeKeyAlias")
    def include_key_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the key column.
        """
        return pulumi.get(self, "include_key_alias")

    @include_key_alias.setter
    def include_key_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_key_alias", value)

    @property
    @pulumi.getter(name="includeOffset")
    def include_offset(self) -> Optional[pulumi.Input[bool]]:
        """
        Include an offset column containing the Kafka message offset.
        """
        return pulumi.get(self, "include_offset")

    @include_offset.setter
    def include_offset(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_offset", value)

    @property
    @pulumi.getter(name="includeOffsetAlias")
    def include_offset_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the offset column.
        """
        return pulumi.get(self, "include_offset_alias")

    @include_offset_alias.setter
    def include_offset_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_offset_alias", value)

    @property
    @pulumi.getter(name="includePartition")
    def include_partition(self) -> Optional[pulumi.Input[bool]]:
        """
        Include a partition column containing the Kafka message partition
        """
        return pulumi.get(self, "include_partition")

    @include_partition.setter
    def include_partition(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_partition", value)

    @property
    @pulumi.getter(name="includePartitionAlias")
    def include_partition_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the partition column.
        """
        return pulumi.get(self, "include_partition_alias")

    @include_partition_alias.setter
    def include_partition_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_partition_alias", value)

    @property
    @pulumi.getter(name="includeTimestamp")
    def include_timestamp(self) -> Optional[pulumi.Input[bool]]:
        """
        Include a timestamp column containing the Kafka message timestamp.
        """
        return pulumi.get(self, "include_timestamp")

    @include_timestamp.setter
    def include_timestamp(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "include_timestamp", value)

    @property
    @pulumi.getter(name="includeTimestampAlias")
    def include_timestamp_alias(self) -> Optional[pulumi.Input[str]]:
        """
        Provide an alias for the timestamp column.
        """
        return pulumi.get(self, "include_timestamp_alias")

    @include_timestamp_alias.setter
    def include_timestamp_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_timestamp_alias", value)

    @property
    @pulumi.getter(name="kafkaConnection")
    def kafka_connection(self) -> Optional[pulumi.Input['SourceKafkaKafkaConnectionArgs']]:
        """
        The Kafka connection to use in the source.
        """
        return pulumi.get(self, "kafka_connection")

    @kafka_connection.setter
    def kafka_connection(self, value: Optional[pulumi.Input['SourceKafkaKafkaConnectionArgs']]):
        pulumi.set(self, "kafka_connection", value)

    @property
    @pulumi.getter(name="keyFormat")
    def key_format(self) -> Optional[pulumi.Input['SourceKafkaKeyFormatArgs']]:
        """
        Set the key format explicitly.
        """
        return pulumi.get(self, "key_format")

    @key_format.setter
    def key_format(self, value: Optional[pulumi.Input['SourceKafkaKeyFormatArgs']]):
        pulumi.set(self, "key_format", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[str]]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="startOffsets")
    def start_offsets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        Read partitions from the specified offset.
        """
        return pulumi.get(self, "start_offsets")

    @start_offsets.setter
    def start_offsets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "start_offsets", value)

    @property
    @pulumi.getter(name="startTimestamp")
    def start_timestamp(self) -> Optional[pulumi.Input[int]]:
        """
        Use the specified value to set `START OFFSET` based on the Kafka timestamp.
        """
        return pulumi.get(self, "start_timestamp")

    @start_timestamp.setter
    def start_timestamp(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "start_timestamp", value)

    @property
    @pulumi.getter
    def topic(self) -> Optional[pulumi.Input[str]]:
        """
        The Kafka topic you want to subscribe to.
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "topic", value)

    @property
    @pulumi.getter(name="valueFormat")
    def value_format(self) -> Optional[pulumi.Input['SourceKafkaValueFormatArgs']]:
        """
        Set the value format explicitly.
        """
        return pulumi.get(self, "value_format")

    @value_format.setter
    def value_format(self, value: Optional[pulumi.Input['SourceKafkaValueFormatArgs']]):
        pulumi.set(self, "value_format", value)


class SourceKafka(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 envelope: Optional[pulumi.Input[pulumi.InputType['SourceKafkaEnvelopeArgs']]] = None,
                 expose_progress: Optional[pulumi.Input[pulumi.InputType['SourceKafkaExposeProgressArgs']]] = None,
                 format: Optional[pulumi.Input[pulumi.InputType['SourceKafkaFormatArgs']]] = None,
                 include_headers: Optional[pulumi.Input[bool]] = None,
                 include_headers_alias: Optional[pulumi.Input[str]] = None,
                 include_key: Optional[pulumi.Input[bool]] = None,
                 include_key_alias: Optional[pulumi.Input[str]] = None,
                 include_offset: Optional[pulumi.Input[bool]] = None,
                 include_offset_alias: Optional[pulumi.Input[str]] = None,
                 include_partition: Optional[pulumi.Input[bool]] = None,
                 include_partition_alias: Optional[pulumi.Input[str]] = None,
                 include_timestamp: Optional[pulumi.Input[bool]] = None,
                 include_timestamp_alias: Optional[pulumi.Input[str]] = None,
                 kafka_connection: Optional[pulumi.Input[pulumi.InputType['SourceKafkaKafkaConnectionArgs']]] = None,
                 key_format: Optional[pulumi.Input[pulumi.InputType['SourceKafkaKeyFormatArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 start_offsets: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 start_timestamp: Optional[pulumi.Input[int]] = None,
                 topic: Optional[pulumi.Input[str]] = None,
                 value_format: Optional[pulumi.Input[pulumi.InputType['SourceKafkaValueFormatArgs']]] = None,
                 __props__=None):
        """
        A Kafka source describes a Kafka cluster you want Materialize to read data from.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_source_kafka = materialize.SourceKafka("exampleSourceKafka",
            cluster_name="quickstart",
            envelope=materialize.SourceKafkaEnvelopeArgs(
                none=True,
            ),
            format=materialize.SourceKafkaFormatArgs(
                avro=materialize.SourceKafkaFormatAvroArgs(
                    schema_registry_connection=materialize.SourceKafkaFormatAvroSchemaRegistryConnectionArgs(
                        database_name="database",
                        name="csr_connection",
                        schema_name="schema",
                    ),
                ),
            ),
            kafka_connection=materialize.SourceKafkaKafkaConnectionArgs(
                database_name="database",
                name="kafka_connection",
                schema_name="schema",
            ),
            schema_name="schema")
        ```

        ## Import

        Sources can be imported using the source id

        ```sh
         $ pulumi import materialize:index/sourceKafka:SourceKafka example_source_kafka <region>:<source_id>
        ```

         Source id and information be found in the `mz_catalog.mz_sources` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[pulumi.InputType['SourceKafkaEnvelopeArgs']] envelope: How Materialize should interpret records (e.g. append-only, upsert)..
        :param pulumi.Input[pulumi.InputType['SourceKafkaExposeProgressArgs']] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[pulumi.InputType['SourceKafkaFormatArgs']] format: How to decode raw bytes from different formats into data structures Materialize can understand at runtime.
        :param pulumi.Input[bool] include_headers: Include message headers.
        :param pulumi.Input[str] include_headers_alias: Provide an alias for the headers column.
        :param pulumi.Input[bool] include_key: Include a column containing the Kafka message key.
        :param pulumi.Input[str] include_key_alias: Provide an alias for the key column.
        :param pulumi.Input[bool] include_offset: Include an offset column containing the Kafka message offset.
        :param pulumi.Input[str] include_offset_alias: Provide an alias for the offset column.
        :param pulumi.Input[bool] include_partition: Include a partition column containing the Kafka message partition
        :param pulumi.Input[str] include_partition_alias: Provide an alias for the partition column.
        :param pulumi.Input[bool] include_timestamp: Include a timestamp column containing the Kafka message timestamp.
        :param pulumi.Input[str] include_timestamp_alias: Provide an alias for the timestamp column.
        :param pulumi.Input[pulumi.InputType['SourceKafkaKafkaConnectionArgs']] kafka_connection: The Kafka connection to use in the source.
        :param pulumi.Input[pulumi.InputType['SourceKafkaKeyFormatArgs']] key_format: Set the key format explicitly.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] start_offsets: Read partitions from the specified offset.
        :param pulumi.Input[int] start_timestamp: Use the specified value to set `START OFFSET` based on the Kafka timestamp.
        :param pulumi.Input[str] topic: The Kafka topic you want to subscribe to.
        :param pulumi.Input[pulumi.InputType['SourceKafkaValueFormatArgs']] value_format: Set the value format explicitly.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SourceKafkaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A Kafka source describes a Kafka cluster you want Materialize to read data from.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_source_kafka = materialize.SourceKafka("exampleSourceKafka",
            cluster_name="quickstart",
            envelope=materialize.SourceKafkaEnvelopeArgs(
                none=True,
            ),
            format=materialize.SourceKafkaFormatArgs(
                avro=materialize.SourceKafkaFormatAvroArgs(
                    schema_registry_connection=materialize.SourceKafkaFormatAvroSchemaRegistryConnectionArgs(
                        database_name="database",
                        name="csr_connection",
                        schema_name="schema",
                    ),
                ),
            ),
            kafka_connection=materialize.SourceKafkaKafkaConnectionArgs(
                database_name="database",
                name="kafka_connection",
                schema_name="schema",
            ),
            schema_name="schema")
        ```

        ## Import

        Sources can be imported using the source id

        ```sh
         $ pulumi import materialize:index/sourceKafka:SourceKafka example_source_kafka <region>:<source_id>
        ```

         Source id and information be found in the `mz_catalog.mz_sources` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param SourceKafkaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SourceKafkaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 envelope: Optional[pulumi.Input[pulumi.InputType['SourceKafkaEnvelopeArgs']]] = None,
                 expose_progress: Optional[pulumi.Input[pulumi.InputType['SourceKafkaExposeProgressArgs']]] = None,
                 format: Optional[pulumi.Input[pulumi.InputType['SourceKafkaFormatArgs']]] = None,
                 include_headers: Optional[pulumi.Input[bool]] = None,
                 include_headers_alias: Optional[pulumi.Input[str]] = None,
                 include_key: Optional[pulumi.Input[bool]] = None,
                 include_key_alias: Optional[pulumi.Input[str]] = None,
                 include_offset: Optional[pulumi.Input[bool]] = None,
                 include_offset_alias: Optional[pulumi.Input[str]] = None,
                 include_partition: Optional[pulumi.Input[bool]] = None,
                 include_partition_alias: Optional[pulumi.Input[str]] = None,
                 include_timestamp: Optional[pulumi.Input[bool]] = None,
                 include_timestamp_alias: Optional[pulumi.Input[str]] = None,
                 kafka_connection: Optional[pulumi.Input[pulumi.InputType['SourceKafkaKafkaConnectionArgs']]] = None,
                 key_format: Optional[pulumi.Input[pulumi.InputType['SourceKafkaKeyFormatArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 start_offsets: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 start_timestamp: Optional[pulumi.Input[int]] = None,
                 topic: Optional[pulumi.Input[str]] = None,
                 value_format: Optional[pulumi.Input[pulumi.InputType['SourceKafkaValueFormatArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SourceKafkaArgs.__new__(SourceKafkaArgs)

            __props__.__dict__["cluster_name"] = cluster_name
            __props__.__dict__["comment"] = comment
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["envelope"] = envelope
            __props__.__dict__["expose_progress"] = expose_progress
            __props__.__dict__["format"] = format
            __props__.__dict__["include_headers"] = include_headers
            __props__.__dict__["include_headers_alias"] = include_headers_alias
            __props__.__dict__["include_key"] = include_key
            __props__.__dict__["include_key_alias"] = include_key_alias
            __props__.__dict__["include_offset"] = include_offset
            __props__.__dict__["include_offset_alias"] = include_offset_alias
            __props__.__dict__["include_partition"] = include_partition
            __props__.__dict__["include_partition_alias"] = include_partition_alias
            __props__.__dict__["include_timestamp"] = include_timestamp
            __props__.__dict__["include_timestamp_alias"] = include_timestamp_alias
            if kafka_connection is None and not opts.urn:
                raise TypeError("Missing required property 'kafka_connection'")
            __props__.__dict__["kafka_connection"] = kafka_connection
            __props__.__dict__["key_format"] = key_format
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["region"] = region
            __props__.__dict__["schema_name"] = schema_name
            __props__.__dict__["start_offsets"] = start_offsets
            __props__.__dict__["start_timestamp"] = start_timestamp
            if topic is None and not opts.urn:
                raise TypeError("Missing required property 'topic'")
            __props__.__dict__["topic"] = topic
            __props__.__dict__["value_format"] = value_format
            __props__.__dict__["qualified_sql_name"] = None
            __props__.__dict__["size"] = None
        super(SourceKafka, __self__).__init__(
            'materialize:index/sourceKafka:SourceKafka',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_name: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            envelope: Optional[pulumi.Input[pulumi.InputType['SourceKafkaEnvelopeArgs']]] = None,
            expose_progress: Optional[pulumi.Input[pulumi.InputType['SourceKafkaExposeProgressArgs']]] = None,
            format: Optional[pulumi.Input[pulumi.InputType['SourceKafkaFormatArgs']]] = None,
            include_headers: Optional[pulumi.Input[bool]] = None,
            include_headers_alias: Optional[pulumi.Input[str]] = None,
            include_key: Optional[pulumi.Input[bool]] = None,
            include_key_alias: Optional[pulumi.Input[str]] = None,
            include_offset: Optional[pulumi.Input[bool]] = None,
            include_offset_alias: Optional[pulumi.Input[str]] = None,
            include_partition: Optional[pulumi.Input[bool]] = None,
            include_partition_alias: Optional[pulumi.Input[str]] = None,
            include_timestamp: Optional[pulumi.Input[bool]] = None,
            include_timestamp_alias: Optional[pulumi.Input[str]] = None,
            kafka_connection: Optional[pulumi.Input[pulumi.InputType['SourceKafkaKafkaConnectionArgs']]] = None,
            key_format: Optional[pulumi.Input[pulumi.InputType['SourceKafkaKeyFormatArgs']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            size: Optional[pulumi.Input[str]] = None,
            start_offsets: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            start_timestamp: Optional[pulumi.Input[int]] = None,
            topic: Optional[pulumi.Input[str]] = None,
            value_format: Optional[pulumi.Input[pulumi.InputType['SourceKafkaValueFormatArgs']]] = None) -> 'SourceKafka':
        """
        Get an existing SourceKafka resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[pulumi.InputType['SourceKafkaEnvelopeArgs']] envelope: How Materialize should interpret records (e.g. append-only, upsert)..
        :param pulumi.Input[pulumi.InputType['SourceKafkaExposeProgressArgs']] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[pulumi.InputType['SourceKafkaFormatArgs']] format: How to decode raw bytes from different formats into data structures Materialize can understand at runtime.
        :param pulumi.Input[bool] include_headers: Include message headers.
        :param pulumi.Input[str] include_headers_alias: Provide an alias for the headers column.
        :param pulumi.Input[bool] include_key: Include a column containing the Kafka message key.
        :param pulumi.Input[str] include_key_alias: Provide an alias for the key column.
        :param pulumi.Input[bool] include_offset: Include an offset column containing the Kafka message offset.
        :param pulumi.Input[str] include_offset_alias: Provide an alias for the offset column.
        :param pulumi.Input[bool] include_partition: Include a partition column containing the Kafka message partition
        :param pulumi.Input[str] include_partition_alias: Provide an alias for the partition column.
        :param pulumi.Input[bool] include_timestamp: Include a timestamp column containing the Kafka message timestamp.
        :param pulumi.Input[str] include_timestamp_alias: Provide an alias for the timestamp column.
        :param pulumi.Input[pulumi.InputType['SourceKafkaKafkaConnectionArgs']] kafka_connection: The Kafka connection to use in the source.
        :param pulumi.Input[pulumi.InputType['SourceKafkaKeyFormatArgs']] key_format: Set the key format explicitly.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this source.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] start_offsets: Read partitions from the specified offset.
        :param pulumi.Input[int] start_timestamp: Use the specified value to set `START OFFSET` based on the Kafka timestamp.
        :param pulumi.Input[str] topic: The Kafka topic you want to subscribe to.
        :param pulumi.Input[pulumi.InputType['SourceKafkaValueFormatArgs']] value_format: Set the value format explicitly.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SourceKafkaState.__new__(_SourceKafkaState)

        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["envelope"] = envelope
        __props__.__dict__["expose_progress"] = expose_progress
        __props__.__dict__["format"] = format
        __props__.__dict__["include_headers"] = include_headers
        __props__.__dict__["include_headers_alias"] = include_headers_alias
        __props__.__dict__["include_key"] = include_key
        __props__.__dict__["include_key_alias"] = include_key_alias
        __props__.__dict__["include_offset"] = include_offset
        __props__.__dict__["include_offset_alias"] = include_offset_alias
        __props__.__dict__["include_partition"] = include_partition
        __props__.__dict__["include_partition_alias"] = include_partition_alias
        __props__.__dict__["include_timestamp"] = include_timestamp
        __props__.__dict__["include_timestamp_alias"] = include_timestamp_alias
        __props__.__dict__["kafka_connection"] = kafka_connection
        __props__.__dict__["key_format"] = key_format
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["size"] = size
        __props__.__dict__["start_offsets"] = start_offsets
        __props__.__dict__["start_timestamp"] = start_timestamp
        __props__.__dict__["topic"] = topic
        __props__.__dict__["value_format"] = value_format
        return SourceKafka(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[str]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def envelope(self) -> pulumi.Output[Optional['outputs.SourceKafkaEnvelope']]:
        """
        How Materialize should interpret records (e.g. append-only, upsert)..
        """
        return pulumi.get(self, "envelope")

    @property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> pulumi.Output[Optional['outputs.SourceKafkaExposeProgress']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @property
    @pulumi.getter
    def format(self) -> pulumi.Output[Optional['outputs.SourceKafkaFormat']]:
        """
        How to decode raw bytes from different formats into data structures Materialize can understand at runtime.
        """
        return pulumi.get(self, "format")

    @property
    @pulumi.getter(name="includeHeaders")
    def include_headers(self) -> pulumi.Output[Optional[bool]]:
        """
        Include message headers.
        """
        return pulumi.get(self, "include_headers")

    @property
    @pulumi.getter(name="includeHeadersAlias")
    def include_headers_alias(self) -> pulumi.Output[Optional[str]]:
        """
        Provide an alias for the headers column.
        """
        return pulumi.get(self, "include_headers_alias")

    @property
    @pulumi.getter(name="includeKey")
    def include_key(self) -> pulumi.Output[Optional[bool]]:
        """
        Include a column containing the Kafka message key.
        """
        return pulumi.get(self, "include_key")

    @property
    @pulumi.getter(name="includeKeyAlias")
    def include_key_alias(self) -> pulumi.Output[Optional[str]]:
        """
        Provide an alias for the key column.
        """
        return pulumi.get(self, "include_key_alias")

    @property
    @pulumi.getter(name="includeOffset")
    def include_offset(self) -> pulumi.Output[Optional[bool]]:
        """
        Include an offset column containing the Kafka message offset.
        """
        return pulumi.get(self, "include_offset")

    @property
    @pulumi.getter(name="includeOffsetAlias")
    def include_offset_alias(self) -> pulumi.Output[Optional[str]]:
        """
        Provide an alias for the offset column.
        """
        return pulumi.get(self, "include_offset_alias")

    @property
    @pulumi.getter(name="includePartition")
    def include_partition(self) -> pulumi.Output[Optional[bool]]:
        """
        Include a partition column containing the Kafka message partition
        """
        return pulumi.get(self, "include_partition")

    @property
    @pulumi.getter(name="includePartitionAlias")
    def include_partition_alias(self) -> pulumi.Output[Optional[str]]:
        """
        Provide an alias for the partition column.
        """
        return pulumi.get(self, "include_partition_alias")

    @property
    @pulumi.getter(name="includeTimestamp")
    def include_timestamp(self) -> pulumi.Output[Optional[bool]]:
        """
        Include a timestamp column containing the Kafka message timestamp.
        """
        return pulumi.get(self, "include_timestamp")

    @property
    @pulumi.getter(name="includeTimestampAlias")
    def include_timestamp_alias(self) -> pulumi.Output[Optional[str]]:
        """
        Provide an alias for the timestamp column.
        """
        return pulumi.get(self, "include_timestamp_alias")

    @property
    @pulumi.getter(name="kafkaConnection")
    def kafka_connection(self) -> pulumi.Output['outputs.SourceKafkaKafkaConnection']:
        """
        The Kafka connection to use in the source.
        """
        return pulumi.get(self, "kafka_connection")

    @property
    @pulumi.getter(name="keyFormat")
    def key_format(self) -> pulumi.Output[Optional['outputs.SourceKafkaKeyFormat']]:
        """
        Set the key format explicitly.
        """
        return pulumi.get(self, "key_format")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[str]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="startOffsets")
    def start_offsets(self) -> pulumi.Output[Optional[Sequence[int]]]:
        """
        Read partitions from the specified offset.
        """
        return pulumi.get(self, "start_offsets")

    @property
    @pulumi.getter(name="startTimestamp")
    def start_timestamp(self) -> pulumi.Output[Optional[int]]:
        """
        Use the specified value to set `START OFFSET` based on the Kafka timestamp.
        """
        return pulumi.get(self, "start_timestamp")

    @property
    @pulumi.getter
    def topic(self) -> pulumi.Output[str]:
        """
        The Kafka topic you want to subscribe to.
        """
        return pulumi.get(self, "topic")

    @property
    @pulumi.getter(name="valueFormat")
    def value_format(self) -> pulumi.Output[Optional['outputs.SourceKafkaValueFormat']]:
        """
        Set the value format explicitly.
        """
        return pulumi.get(self, "value_format")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 roles: pulumi.Input[Sequence[pulumi.Input[str]]],
                 send_activation_email: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[str] email: The email address of the user. This must be unique across all users in the organization.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        :param pulumi.Input[bool] send_activation_email: Whether to send an email either inviting the user to activate their account, if the user is new, or inviting the user to join the organization, if the user already exists in another organization. Changing this property after the resource is created has no effect.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "roles", roles)
        if send_activation_email is not None:
            pulumi.set(__self__, "send_activation_email", send_activation_email)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        The email address of the user. This must be unique across all users in the organization.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter(name="sendActivationEmail")
    def send_activation_email(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to send an email either inviting the user to activate their account, if the user is new, or inviting the user to join the organization, if the user already exists in another organization. Changing this property after the resource is created has no effect.
        """
        return pulumi.get(self, "send_activation_email")

    @send_activation_email.setter
    def send_activation_email(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_activation_email", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 auth_provider: Optional[pulumi.Input[str]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 send_activation_email: Optional[pulumi.Input[bool]] = None,
                 verified: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[str] auth_provider: The authentication provider for the user.
        :param pulumi.Input[str] email: The email address of the user. This must be unique across all users in the organization.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        :param pulumi.Input[bool] send_activation_email: Whether to send an email either inviting the user to activate their account, if the user is new, or inviting the user to join the organization, if the user already exists in another organization. Changing this property after the resource is created has no effect.
        """
        if auth_provider is not None:
            pulumi.set(__self__, "auth_provider", auth_provider)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if send_activation_email is not None:
            pulumi.set(__self__, "send_activation_email", send_activation_email)
        if verified is not None:
            pulumi.set(__self__, "verified", verified)

    @property
    @pulumi.getter(name="authProvider")
    def auth_provider(self) -> Optional[pulumi.Input[str]]:
        """
        The authentication provider for the user.
        """
        return pulumi.get(self, "auth_provider")

    @auth_provider.setter
    def auth_provider(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_provider", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        The email address of the user. This must be unique across all users in the organization.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter(name="sendActivationEmail")
    def send_activation_email(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to send an email either inviting the user to activate their account, if the user is new, or inviting the user to join the organization, if the user already exists in another organization. Changing this property after the resource is created has no effect.
        """
        return pulumi.get(self, "send_activation_email")

    @send_activation_email.setter
    def send_activation_email(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_activation_email", value)

    @property
    @pulumi.getter
    def verified(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "verified")

    @verified.setter
    def verified(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "verified", value)


class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 send_activation_email: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_user = materialize.User("exampleUser",
            email="example-user@example.com",
            roles=[
                "Member",
                "Admin",
            ])
        ```

        ## Import

        Users can be imported using the user id

        ```sh
         $ pulumi import materialize:index/user:User example_user <user_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The email address of the user. This must be unique across all users in the organization.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        :param pulumi.Input[bool] send_activation_email: Whether to send an email either inviting the user to activate their account, if the user is new, or inviting the user to join the organization, if the user already exists in another organization. Changing this property after the resource is created has no effect.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_user = materialize.User("exampleUser",
            email="example-user@example.com",
            roles=[
                "Member",
                "Admin",
            ])
        ```

        ## Import

        Users can be imported using the user id

        ```sh
         $ pulumi import materialize:index/user:User example_user <user_id>
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 send_activation_email: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            if roles is None and not opts.urn:
                raise TypeError("Missing required property 'roles'")
            __props__.__dict__["roles"] = roles
            __props__.__dict__["send_activation_email"] = send_activation_email
            __props__.__dict__["auth_provider"] = None
            __props__.__dict__["metadata"] = None
            __props__.__dict__["verified"] = None
        super(User, __self__).__init__(
            'materialize:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_provider: Optional[pulumi.Input[str]] = None,
            email: Optional[pulumi.Input[str]] = None,
            metadata: Optional[pulumi.Input[str]] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            send_activation_email: Optional[pulumi.Input[bool]] = None,
            verified: Optional[pulumi.Input[bool]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auth_provider: The authentication provider for the user.
        :param pulumi.Input[str] email: The email address of the user. This must be unique across all users in the organization.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        :param pulumi.Input[bool] send_activation_email: Whether to send an email either inviting the user to activate their account, if the user is new, or inviting the user to join the organization, if the user already exists in another organization. Changing this property after the resource is created has no effect.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["auth_provider"] = auth_provider
        __props__.__dict__["email"] = email
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["roles"] = roles
        __props__.__dict__["send_activation_email"] = send_activation_email
        __props__.__dict__["verified"] = verified
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authProvider")
    def auth_provider(self) -> pulumi.Output[str]:
        """
        The authentication provider for the user.
        """
        return pulumi.get(self, "auth_provider")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[str]:
        """
        The email address of the user. This must be unique across all users in the organization.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[str]:
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Sequence[str]]:
        """
        The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter(name="sendActivationEmail")
    def send_activation_email(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to send an email either inviting the user to activate their account, if the user is new, or inviting the user to join the organization, if the user already exists in another organization. Changing this property after the resource is created has no effect.
        """
        return pulumi.get(self, "send_activation_email")

    @property
    @pulumi.getter
    def verified(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "verified")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['SCIM2GroupUsersArgs', 'SCIM2GroupUsers']

@pulumi.input_type
class SCIM2GroupUsersArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[str],
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a SCIM2GroupUsers resource.
        :param pulumi.Input[str] group_id: The ID of the SCIM group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] users: The set of user IDs to assign to the SCIM group.
        """
        pulumi.set(__self__, "group_id", group_id)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[str]:
        """
        The ID of the SCIM group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The set of user IDs to assign to the SCIM group.
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "users", value)


@pulumi.input_type
class _SCIM2GroupUsersState:
    def __init__(__self__, *,
                 group_id: Optional[pulumi.Input[str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering SCIM2GroupUsers resources.
        :param pulumi.Input[str] group_id: The ID of the SCIM group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] users: The set of user IDs to assign to the SCIM group.
        """
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the SCIM group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The set of user IDs to assign to the SCIM group.
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "users", value)


class SCIM2GroupUsers(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        The SCIM2GroupUsers resource allows managing users within a SCIM group in Frontegg.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a SCIM group users resource
        example_users1 = materialize.User("exampleUsers1",
            email="example-user1@example.com",
            roles=["Member"])
        example_users2 = materialize.User("exampleUsers2",
            email="example-user2@example.com",
            roles=["Member"])
        example_scim_group_users = materialize.SCIM2GroupUsers("exampleScimGroupUsers",
            group_id=materialize_scim_group["example_scim_group"]["id"],
            users=[
                example_users1.id,
                example_users2.id,
            ])
        ```

        ## Import

        SCIM group ID can be found using the `materialize_scim_groups` data source.

        ```sh
         $ pulumi import materialize:index/sCIM2GroupUsers:SCIM2GroupUsers example_scim_group_user <scim_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_id: The ID of the SCIM group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] users: The set of user IDs to assign to the SCIM group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SCIM2GroupUsersArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The SCIM2GroupUsers resource allows managing users within a SCIM group in Frontegg.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Create a SCIM group users resource
        example_users1 = materialize.User("exampleUsers1",
            email="example-user1@example.com",
            roles=["Member"])
        example_users2 = materialize.User("exampleUsers2",
            email="example-user2@example.com",
            roles=["Member"])
        example_scim_group_users = materialize.SCIM2GroupUsers("exampleScimGroupUsers",
            group_id=materialize_scim_group["example_scim_group"]["id"],
            users=[
                example_users1.id,
                example_users2.id,
            ])
        ```

        ## Import

        SCIM group ID can be found using the `materialize_scim_groups` data source.

        ```sh
         $ pulumi import materialize:index/sCIM2GroupUsers:SCIM2GroupUsers example_scim_group_user <scim_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param SCIM2GroupUsersArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SCIM2GroupUsersArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SCIM2GroupUsersArgs.__new__(SCIM2GroupUsersArgs)

            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["users"] = users
        super(SCIM2GroupUsers, __self__).__init__(
            'materialize:index/sCIM2GroupUsers:SCIM2GroupUsers',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'SCIM2GroupUsers':
        """
        Get an existing SCIM2GroupUsers resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_id: The ID of the SCIM group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] users: The set of user IDs to assign to the SCIM group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SCIM2GroupUsersState.__new__(_SCIM2GroupUsersState)

        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["users"] = users
        return SCIM2GroupUsers(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[str]:
        """
        The ID of the SCIM group.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def users(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The set of user IDs to assign to the SCIM group.
        """
        return pulumi.get(self, "users")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['SSOConfigArgs', 'SSOConfig']

@pulumi.input_type
class SSOConfigArgs:
    def __init__(__self__, *,
                 enabled: pulumi.Input[bool],
                 public_certificate: pulumi.Input[str],
                 sign_request: pulumi.Input[bool],
                 sso_endpoint: pulumi.Input[str],
                 type: pulumi.Input[str],
                 oidc_client_id: Optional[pulumi.Input[str]] = None,
                 oidc_secret: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SSOConfig resource.
        :param pulumi.Input[bool] enabled: Whether SSO is enabled or not. If enabled, users will be redirected to the SSO endpoint for authentication. The configuration needs to be valid for SSO to work.
        :param pulumi.Input[str] public_certificate: The public certificate of the SSO service. This is used to verify the SSO response. The certificate must be in PEM format. The certificate must be accessible from the browser. If the certificate is not accessible from the browser, you can use the public certificate of the Identity Provider (IdP) instead.
        :param pulumi.Input[bool] sign_request: Indicates whether the SSO request needs to be digitally signed.
        :param pulumi.Input[str] sso_endpoint: The URL endpoint for the SSO service. This is the URL that users will be redirected to for authentication. The URL must be accessible from the browser.
        :param pulumi.Input[str] type: Defines the type of SSO protocol being used (e.g., saml, oidc).
        :param pulumi.Input[str] oidc_client_id: The client ID of the OIDC application. This is used to identify the application to the OIDC service. This is required if the type is OIDC.
        :param pulumi.Input[str] oidc_secret: The client secret of the OIDC application. This is used to authenticate the application to the OIDC service. This is required if the type is OIDC.
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "public_certificate", public_certificate)
        pulumi.set(__self__, "sign_request", sign_request)
        pulumi.set(__self__, "sso_endpoint", sso_endpoint)
        pulumi.set(__self__, "type", type)
        if oidc_client_id is not None:
            pulumi.set(__self__, "oidc_client_id", oidc_client_id)
        if oidc_secret is not None:
            pulumi.set(__self__, "oidc_secret", oidc_secret)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[bool]:
        """
        Whether SSO is enabled or not. If enabled, users will be redirected to the SSO endpoint for authentication. The configuration needs to be valid for SSO to work.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[bool]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="publicCertificate")
    def public_certificate(self) -> pulumi.Input[str]:
        """
        The public certificate of the SSO service. This is used to verify the SSO response. The certificate must be in PEM format. The certificate must be accessible from the browser. If the certificate is not accessible from the browser, you can use the public certificate of the Identity Provider (IdP) instead.
        """
        return pulumi.get(self, "public_certificate")

    @public_certificate.setter
    def public_certificate(self, value: pulumi.Input[str]):
        pulumi.set(self, "public_certificate", value)

    @property
    @pulumi.getter(name="signRequest")
    def sign_request(self) -> pulumi.Input[bool]:
        """
        Indicates whether the SSO request needs to be digitally signed.
        """
        return pulumi.get(self, "sign_request")

    @sign_request.setter
    def sign_request(self, value: pulumi.Input[bool]):
        pulumi.set(self, "sign_request", value)

    @property
    @pulumi.getter(name="ssoEndpoint")
    def sso_endpoint(self) -> pulumi.Input[str]:
        """
        The URL endpoint for the SSO service. This is the URL that users will be redirected to for authentication. The URL must be accessible from the browser.
        """
        return pulumi.get(self, "sso_endpoint")

    @sso_endpoint.setter
    def sso_endpoint(self, value: pulumi.Input[str]):
        pulumi.set(self, "sso_endpoint", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Defines the type of SSO protocol being used (e.g., saml, oidc).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> Optional[pulumi.Input[str]]:
        """
        The client ID of the OIDC application. This is used to identify the application to the OIDC service. This is required if the type is OIDC.
        """
        return pulumi.get(self, "oidc_client_id")

    @oidc_client_id.setter
    def oidc_client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_client_id", value)

    @property
    @pulumi.getter(name="oidcSecret")
    def oidc_secret(self) -> Optional[pulumi.Input[str]]:
        """
        The client secret of the OIDC application. This is used to authenticate the application to the OIDC service. This is required if the type is OIDC.
        """
        return pulumi.get(self, "oidc_secret")

    @oidc_secret.setter
    def oidc_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_secret", value)


@pulumi.input_type
class _SSOConfigState:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[str]] = None,
                 oidc_secret: Optional[pulumi.Input[str]] = None,
                 public_certificate: Optional[pulumi.Input[str]] = None,
                 sign_request: Optional[pulumi.Input[bool]] = None,
                 sso_endpoint: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SSOConfig resources.
        :param pulumi.Input[bool] enabled: Whether SSO is enabled or not. If enabled, users will be redirected to the SSO endpoint for authentication. The configuration needs to be valid for SSO to work.
        :param pulumi.Input[str] oidc_client_id: The client ID of the OIDC application. This is used to identify the application to the OIDC service. This is required if the type is OIDC.
        :param pulumi.Input[str] oidc_secret: The client secret of the OIDC application. This is used to authenticate the application to the OIDC service. This is required if the type is OIDC.
        :param pulumi.Input[str] public_certificate: The public certificate of the SSO service. This is used to verify the SSO response. The certificate must be in PEM format. The certificate must be accessible from the browser. If the certificate is not accessible from the browser, you can use the public certificate of the Identity Provider (IdP) instead.
        :param pulumi.Input[bool] sign_request: Indicates whether the SSO request needs to be digitally signed.
        :param pulumi.Input[str] sso_endpoint: The URL endpoint for the SSO service. This is the URL that users will be redirected to for authentication. The URL must be accessible from the browser.
        :param pulumi.Input[str] type: Defines the type of SSO protocol being used (e.g., saml, oidc).
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if oidc_client_id is not None:
            pulumi.set(__self__, "oidc_client_id", oidc_client_id)
        if oidc_secret is not None:
            pulumi.set(__self__, "oidc_secret", oidc_secret)
        if public_certificate is not None:
            pulumi.set(__self__, "public_certificate", public_certificate)
        if sign_request is not None:
            pulumi.set(__self__, "sign_request", sign_request)
        if sso_endpoint is not None:
            pulumi.set(__self__, "sso_endpoint", sso_endpoint)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether SSO is enabled or not. If enabled, users will be redirected to the SSO endpoint for authentication. The configuration needs to be valid for SSO to work.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> Optional[pulumi.Input[str]]:
        """
        The client ID of the OIDC application. This is used to identify the application to the OIDC service. This is required if the type is OIDC.
        """
        return pulumi.get(self, "oidc_client_id")

    @oidc_client_id.setter
    def oidc_client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_client_id", value)

    @property
    @pulumi.getter(name="oidcSecret")
    def oidc_secret(self) -> Optional[pulumi.Input[str]]:
        """
        The client secret of the OIDC application. This is used to authenticate the application to the OIDC service. This is required if the type is OIDC.
        """
        return pulumi.get(self, "oidc_secret")

    @oidc_secret.setter
    def oidc_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_secret", value)

    @property
    @pulumi.getter(name="publicCertificate")
    def public_certificate(self) -> Optional[pulumi.Input[str]]:
        """
        The public certificate of the SSO service. This is used to verify the SSO response. The certificate must be in PEM format. The certificate must be accessible from the browser. If the certificate is not accessible from the browser, you can use the public certificate of the Identity Provider (IdP) instead.
        """
        return pulumi.get(self, "public_certificate")

    @public_certificate.setter
    def public_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "public_certificate", value)

    @property
    @pulumi.getter(name="signRequest")
    def sign_request(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether the SSO request needs to be digitally signed.
        """
        return pulumi.get(self, "sign_request")

    @sign_request.setter
    def sign_request(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sign_request", value)

    @property
    @pulumi.getter(name="ssoEndpoint")
    def sso_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The URL endpoint for the SSO service. This is the URL that users will be redirected to for authentication. The URL must be accessible from the browser.
        """
        return pulumi.get(self, "sso_endpoint")

    @sso_endpoint.setter
    def sso_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sso_endpoint", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the type of SSO protocol being used (e.g., saml, oidc).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class SSOConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[str]] = None,
                 oidc_secret: Optional[pulumi.Input[str]] = None,
                 public_certificate: Optional[pulumi.Input[str]] = None,
                 sign_request: Optional[pulumi.Input[bool]] = None,
                 sso_endpoint: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The SSO configuration resource allows you to create, read, update, and delete SSO configurations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sso_config = materialize.SSOConfig("exampleSsoConfig",
            enabled=True,
            oidc_client_id="client-id",
            oidc_secret="client-secret",
            public_certificate="PUBLIC_CERTIFICATE",
            sign_request=True,
            sso_endpoint="https://sso.example2.com",
            type="saml")
        ```

        ## Import

        The SSO Configuration ID can be found using the `materialize_sso_config` data source

        ```sh
         $ pulumi import materialize:index/sSOConfig:SSOConfig example <sso_config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enabled: Whether SSO is enabled or not. If enabled, users will be redirected to the SSO endpoint for authentication. The configuration needs to be valid for SSO to work.
        :param pulumi.Input[str] oidc_client_id: The client ID of the OIDC application. This is used to identify the application to the OIDC service. This is required if the type is OIDC.
        :param pulumi.Input[str] oidc_secret: The client secret of the OIDC application. This is used to authenticate the application to the OIDC service. This is required if the type is OIDC.
        :param pulumi.Input[str] public_certificate: The public certificate of the SSO service. This is used to verify the SSO response. The certificate must be in PEM format. The certificate must be accessible from the browser. If the certificate is not accessible from the browser, you can use the public certificate of the Identity Provider (IdP) instead.
        :param pulumi.Input[bool] sign_request: Indicates whether the SSO request needs to be digitally signed.
        :param pulumi.Input[str] sso_endpoint: The URL endpoint for the SSO service. This is the URL that users will be redirected to for authentication. The URL must be accessible from the browser.
        :param pulumi.Input[str] type: Defines the type of SSO protocol being used (e.g., saml, oidc).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SSOConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The SSO configuration resource allows you to create, read, update, and delete SSO configurations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sso_config = materialize.SSOConfig("exampleSsoConfig",
            enabled=True,
            oidc_client_id="client-id",
            oidc_secret="client-secret",
            public_certificate="PUBLIC_CERTIFICATE",
            sign_request=True,
            sso_endpoint="https://sso.example2.com",
            type="saml")
        ```

        ## Import

        The SSO Configuration ID can be found using the `materialize_sso_config` data source

        ```sh
         $ pulumi import materialize:index/sSOConfig:SSOConfig example <sso_config_id>
        ```

        :param str resource_name: The name of the resource.
        :param SSOConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SSOConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 oidc_client_id: Optional[pulumi.Input[str]] = None,
                 oidc_secret: Optional[pulumi.Input[str]] = None,
                 public_certificate: Optional[pulumi.Input[str]] = None,
                 sign_request: Optional[pulumi.Input[bool]] = None,
                 sso_endpoint: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SSOConfigArgs.__new__(SSOConfigArgs)

            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["oidc_client_id"] = oidc_client_id
            __props__.__dict__["oidc_secret"] = oidc_secret
            if public_certificate is None and not opts.urn:
                raise TypeError("Missing required property 'public_certificate'")
            __props__.__dict__["public_certificate"] = public_certificate
            if sign_request is None and not opts.urn:
                raise TypeError("Missing required property 'sign_request'")
            __props__.__dict__["sign_request"] = sign_request
            if sso_endpoint is None and not opts.urn:
                raise TypeError("Missing required property 'sso_endpoint'")
            __props__.__dict__["sso_endpoint"] = sso_endpoint
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(SSOConfig, __self__).__init__(
            'materialize:index/sSOConfig:SSOConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            oidc_client_id: Optional[pulumi.Input[str]] = None,
            oidc_secret: Optional[pulumi.Input[str]] = None,
            public_certificate: Optional[pulumi.Input[str]] = None,
            sign_request: Optional[pulumi.Input[bool]] = None,
            sso_endpoint: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'SSOConfig':
        """
        Get an existing SSOConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enabled: Whether SSO is enabled or not. If enabled, users will be redirected to the SSO endpoint for authentication. The configuration needs to be valid for SSO to work.
        :param pulumi.Input[str] oidc_client_id: The client ID of the OIDC application. This is used to identify the application to the OIDC service. This is required if the type is OIDC.
        :param pulumi.Input[str] oidc_secret: The client secret of the OIDC application. This is used to authenticate the application to the OIDC service. This is required if the type is OIDC.
        :param pulumi.Input[str] public_certificate: The public certificate of the SSO service. This is used to verify the SSO response. The certificate must be in PEM format. The certificate must be accessible from the browser. If the certificate is not accessible from the browser, you can use the public certificate of the Identity Provider (IdP) instead.
        :param pulumi.Input[bool] sign_request: Indicates whether the SSO request needs to be digitally signed.
        :param pulumi.Input[str] sso_endpoint: The URL endpoint for the SSO service. This is the URL that users will be redirected to for authentication. The URL must be accessible from the browser.
        :param pulumi.Input[str] type: Defines the type of SSO protocol being used (e.g., saml, oidc).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SSOConfigState.__new__(_SSOConfigState)

        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["oidc_client_id"] = oidc_client_id
        __props__.__dict__["oidc_secret"] = oidc_secret
        __props__.__dict__["public_certificate"] = public_certificate
        __props__.__dict__["sign_request"] = sign_request
        __props__.__dict__["sso_endpoint"] = sso_endpoint
        __props__.__dict__["type"] = type
        return SSOConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[bool]:
        """
        Whether SSO is enabled or not. If enabled, users will be redirected to the SSO endpoint for authentication. The configuration needs to be valid for SSO to work.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="oidcClientId")
    def oidc_client_id(self) -> pulumi.Output[Optional[str]]:
        """
        The client ID of the OIDC application. This is used to identify the application to the OIDC service. This is required if the type is OIDC.
        """
        return pulumi.get(self, "oidc_client_id")

    @property
    @pulumi.getter(name="oidcSecret")
    def oidc_secret(self) -> pulumi.Output[Optional[str]]:
        """
        The client secret of the OIDC application. This is used to authenticate the application to the OIDC service. This is required if the type is OIDC.
        """
        return pulumi.get(self, "oidc_secret")

    @property
    @pulumi.getter(name="publicCertificate")
    def public_certificate(self) -> pulumi.Output[str]:
        """
        The public certificate of the SSO service. This is used to verify the SSO response. The certificate must be in PEM format. The certificate must be accessible from the browser. If the certificate is not accessible from the browser, you can use the public certificate of the Identity Provider (IdP) instead.
        """
        return pulumi.get(self, "public_certificate")

    @property
    @pulumi.getter(name="signRequest")
    def sign_request(self) -> pulumi.Output[bool]:
        """
        Indicates whether the SSO request needs to be digitally signed.
        """
        return pulumi.get(self, "sign_request")

    @property
    @pulumi.getter(name="ssoEndpoint")
    def sso_endpoint(self) -> pulumi.Output[str]:
        """
        The URL endpoint for the SSO service. This is the URL that users will be redirected to for authentication. The URL must be accessible from the browser.
        """
        return pulumi.get(self, "sso_endpoint")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        Defines the type of SSO protocol being used (e.g., saml, oidc).
        """
        return pulumi.get(self, "type")

